==> mysql-5.7.29.tar.gz: mysql-5.7.29/storage/ndb/src/ndbjtie/com/mysql/ndbjtie/ndbapi/NdbScanFilterConst.java <==
/*
  Copyright 2010 Sun Microsystems, Inc.
  All rights reserved. Use is subject to license terms.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * NdbScanFilterConst.java
 */

package com.mysql.ndbjtie.ndbapi;

import java.nio.ByteBuffer;

import com.mysql.jtie.Wrapper;

public interface NdbScanFilterConst
{
    NdbErrorConst/*_const NdbError &_*/ getNdbError() /*_const_*/;
    NdbInterpretedCodeConst/*_const NdbInterpretedCode *_*/ getInterpretedCode() /*_const_*/;
    NdbOperation/*_NdbOperation *_*/ getNdbOperation() /*_const_*/;
}

==> mysql-8.4.6.tar.gz: mysql-8.4.6/storage/ndb/src/ndbjtie/com/mysql/ndbjtie/ndbapi/NdbScanFilterConst.java <==
/*
  Copyright (c) 2010, 2025, Oracle and/or its affiliates.
  Use is subject to license terms.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * NdbScanFilterConst.java
 */

package com.mysql.ndbjtie.ndbapi;

import java.nio.ByteBuffer;

import com.mysql.jtie.Wrapper;

public interface NdbScanFilterConst
{
    NdbErrorConst/*_const NdbError &_*/ getNdbError() /*_const_*/;
    NdbInterpretedCodeConst/*_const NdbInterpretedCode *_*/ getInterpretedCode() /*_const_*/;
    NdbOperation/*_NdbOperation *_*/ getNdbOperation() /*_const_*/;
}
